@@ -97,7 +97,6 @@ GSS_CALLCONV gss_import_name(
     int                                 length, i;
     char *                              name_buffer = NULL;
     char *                              index;
-    static char *                       _function_name_ = "gss_import_name";
 
     GLOBUS_I_GSI_GSSAPI_DEBUG_ENTER;
 
@@ -143,7 +142,7 @@ GSS_CALLCONV gss_import_name(
     }
     else if (g_OID_equal(GSS_C_NT_HOSTBASED_SERVICE, input_name_type))
     {
-        name_buffer = globus_libc_strdup(input_name_buffer->value);
+        name_buffer = malloc(input_name_buffer->length+1);
         if (name_buffer == NULL)
         {
             GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
@@ -151,6 +150,11 @@ GSS_CALLCONV gss_import_name(
             goto release_name_out;
         }
 
+        memcpy(name_buffer,
+               input_name_buffer->value,
+               input_name_buffer->length);
+        name_buffer[input_name_buffer->length] = '\0';
+
         index = strchr(name_buffer, '@');
         if (index)
         {
@@ -171,6 +175,13 @@ GSS_CALLCONV gss_import_name(
             output_name->host_name = name_buffer;
             name_buffer = NULL;
             output_name->service_name = globus_libc_strdup("host");
+            if (output_name->service_name == NULL)
+            {
+                GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
+                major_status = GSS_S_FAILURE;
+
+                goto release_name_out;
+            }
         }
         name_buffer = globus_common_create_string(
                 "/CN=%s%s%s",
@@ -269,7 +280,7 @@ GSS_CALLCONV gss_import_name(
     else if (g_OID_equal(GSS_C_NO_OID, input_name_type) ||
              g_OID_equal(GSS_C_NT_USER_NAME, input_name_type))
     {
-        output_name->user_name = globus_libc_strdup(input_name_buffer->value);
+        output_name->user_name = malloc(input_name_buffer->length + 1);
         if (output_name->user_name == NULL)
         {
             GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
@@ -277,6 +288,11 @@ GSS_CALLCONV gss_import_name(
 
             goto release_name_out;
         }
+        memcpy(output_name->user_name,
+               input_name_buffer->value, 
+               input_name_buffer->length);
+        output_name->user_name[input_name_buffer->length] = '\0';
+
         local_result = globus_gsi_cert_utils_get_x509_name(
                 output_name->user_name,
                 strlen(output_name->user_name),
@@ -308,7 +324,7 @@ GSS_CALLCONV gss_import_name(
     }
     else if (g_OID_equal(GLOBUS_GSS_C_NT_HOST_IP, input_name_type))
     {
-        name_buffer = globus_libc_strdup(input_name_buffer->value);
+        name_buffer = malloc(input_name_buffer->length+1);
         if (name_buffer == NULL)
         {
             GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
@@ -316,27 +332,45 @@ GSS_CALLCONV gss_import_name(
 
             goto release_name_out;
         }
+        memcpy(name_buffer,
+               input_name_buffer->value, input_name_buffer->length);
+        name_buffer[input_name_buffer->length] = '\0';
 
         index = strchr(name_buffer, '/');
         if (index)
         {
             *index = '\0';
-            output_name->host_name = name_buffer;
-            name_buffer = NULL;
-            output_name->ip_address = globus_libc_strdup(index+1);
+            if (index == name_buffer)
+            {
+                output_name->host_name = NULL;
+            }
+            else
+            {
+                output_name->host_name = name_buffer;
+                name_buffer = NULL;
+            }
+            if (strlen(index+1) > 0)
+            {
+                output_name->ip_address = globus_libc_strdup(index+1);
+
+                if (output_name->ip_address == NULL)
+                {
+                    GLOBUS_GSI_GSSAPI_MALLOC_ERROR(minor_status);
+                    major_status = GSS_S_FAILURE;
+
+                    goto release_name_out;
+                }
+            }
+            else
+            {
+                output_name->ip_address = NULL;
+            }
         }
         else
         {
-            free(name_buffer);
+            output_name->host_name = name_buffer;
             name_buffer = NULL;
-
-            major_status = GSS_S_BAD_NAME;
-
-            GLOBUS_GSI_GSSAPI_OPENSSL_ERROR_RESULT(
-                    minor_status,
-                    GLOBUS_GSI_GSSAPI_ERROR_BAD_NAME,
-                    (_GGSL("Bad name")));
-            goto release_name_out;
+            output_name->ip_address = NULL;
         }
         name_buffer = globus_common_create_string(
                 "/CN=%s",
@@ -377,11 +411,24 @@ GSS_CALLCONV gss_import_name(
     }
     else if (g_OID_equal(GLOBUS_GSS_C_NT_X509, input_name_type))
     {
-        X509_NAME * n;
-        X509 * x509_input = input_name_buffer->value;
-        GENERAL_NAMES * subject_alt_name;
-        int idx;
+        X509_NAME                      *n;
+        X509                           *x509_input;
+        GENERAL_NAMES                  *subject_alt_name;
+        int                             idx;
 
+        if (input_name_buffer->length != sizeof(X509))
+        {
+            /* Invalid input */
+            GLOBUS_GSI_GSSAPI_OPENSSL_ERROR_RESULT(
+                    minor_status,
+                    GLOBUS_GSI_GSSAPI_ERROR_BAD_ARGUMENT,
+                    (_GGSL("Invalid parameter")));
+            major_status = GSS_S_FAILURE;
+
+            goto release_name_out;
+        }
+
+        x509_input = input_name_buffer->value;
         /* Extract SubjectName if present */
         if ((n = X509_get_subject_name(x509_input)) != NULL)
         {
@@ -478,12 +525,14 @@ gss_l_resolve_ip(
     OM_uint32 *                         minor_status,
     gss_name_desc *                     name)
 {
+#ifndef NI_MAXHOST
+#define NI_MAXHOST 1025
+#endif
     char                                realhostname[NI_MAXHOST + 1];
     OM_uint32                           major_status;
     globus_result_t                     result = GLOBUS_SUCCESS;
     globus_addrinfo_t                   hints;
     globus_addrinfo_t *                 addrinfo = NULL;
-    static char *                       _function_name_ = "gss_l_resolve_ip";
 
     major_status = GSS_S_COMPLETE;
 
